@@ -162,8 +162,8 @@
 	/* end font funcs and vars */
 
 	/* accessibility funcs and vars */
-	GtkWidget *access_drawing_area;
-	StockData *access_stock;
+	static GtkWidget *access_drawing_area;
+	static StockData *access_stock;
 
 	extern void set_relation (GtkWidget *widget, GtkLabel *label);
 	static void setup_refchild_nchildren(GtkWidget * vbox);
@@ -457,8 +457,9 @@ static gint updateOutput(gpointer data)
                 change[strlen(change) -1] = 0;
                 change[strlen(change) -1] = 0;
                 change_val = strtod(change, NULL); 
-                
-                percent = (change_val/price_val)*1E+02; 
+               
+		/* GNOME Bug 143737 - prothonotar@tarnation.dyndns.org */ 
+                percent = (change_val/(price_val-change_val))*1E+02; 
 
                 /* Restore numeric format for displaying */
                 setlocale(LC_NUMERIC, getenv("LANG"));
@@ -705,9 +706,7 @@ static gint updateOutput(gpointer data)
 	static void about_cb (BonoboUIComponent *uic,
 			      StockData         *stockdata, 
 			      const gchar       *verbname) {
-		GdkPixbuf *pixbuf;
-		GError    *error = NULL;
-		gchar     *file;
+
 		static const gchar *authors[] = {
 			"Jayson Lorenzen <jayson_lorenzen@yahoo.com>",
 			"Jim Garrison <garrison@users.sourceforge.net>",
@@ -720,54 +719,25 @@ static gint updateOutput(gpointer data)
 			NULL
 		};
 
-		const gchar *translator_credits = _("translator_credits");
-
-		if (stockdata->about_dialog) {
-			gtk_window_set_screen (GTK_WINDOW (stockdata->about_dialog),
-					       gtk_widget_get_screen (stockdata->applet));
-
-			gtk_window_present (GTK_WINDOW (stockdata->about_dialog));
-			return;
-		}
-
-		file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-			"gnome-money.png", FALSE, NULL);
-		
-		pixbuf = gdk_pixbuf_new_from_file (file, &error);
-		
-		g_free (file);
-		
-		if (error) {
-			g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-			
-			g_error_free (error);
-		}
-		
-		stockdata->about_dialog = gnome_about_new (_("Stock Ticker"), VERSION,
-		"(C) 2000 Jayson Lorenzen, Jim Garrison, Rached Blili",
-		_("This program connects to "
-		"a popular site and downloads current stock quotes.  "
-		"The GNOME Stock Ticker is a free Internet-based application.  "
-		"It comes with ABSOLUTELY NO WARRANTY.  "
-		"Do not use the GNOME Stock Ticker for making investment decisions; it is for "
-		"informational purposes only."),
-		authors,
-		documenters,
-		strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-		pixbuf);
-		
-		if (pixbuf)
-			gdk_pixbuf_unref (pixbuf);
-
-		gtk_window_set_screen (GTK_WINDOW (stockdata->about_dialog),
-				       gtk_widget_get_screen (stockdata->applet));
-
-		g_signal_connect(G_OBJECT (stockdata->about_dialog), "destroy",
-				 G_CALLBACK (gtk_widget_destroyed), &stockdata->about_dialog);
-
-		gtk_widget_show (stockdata->about_dialog);
-
-		return;
+		gtk_show_about_dialog(NULL,
+			"name",		_("Stock Ticker"),
+			"version",	VERSION,
+			"copyright",	"\xC2\xA9 2000 Jayson Lorenzen, "
+					"Jim Garrison, Rached Blili",
+			"comments",	_("This program connects to "
+					"a popular site and downloads current "
+					"stock quotes.\n\n"
+					"The GNOME Stock Ticker is a free "
+					"Internet-based application. It comes "
+					"with ABSOLUTELY NO WARRANTY.\n\n"
+					"Do not use the GNOME Stock Ticker for "
+					"making investment decisions; it is "
+					"for informational purposes only."),
+			"authors",	authors,
+			"documenters",	documenters,
+			"translator-credits",	_("translator-credits"),
+			"logo_icon_name",	"gnome-money",
+			NULL);
 	}
 
 	static void help_cb (BonoboUIComponent *uic,
@@ -1275,7 +1245,7 @@ static gint updateOutput(gpointer data)
 		
 		hbox = gtk_hbox_new (FALSE, 12);
 		gtk_box_pack_start (GTK_BOX (mainhbox), hbox, FALSE, FALSE, 0);
-		label = gtk_label_new_with_mnemonic (_("_New symbol:"));
+		label = gtk_label_new_with_mnemonic (_("Add _new symbol:"));
 		gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
 		entry = gtk_entry_new();
 		g_object_set_data(G_OBJECT(entry),"list",(gpointer)list);
@@ -1283,9 +1253,7 @@ static gint updateOutput(gpointer data)
 		g_signal_connect (G_OBJECT (entry), "activate",
 				  G_CALLBACK (add_symbol), stockdata);		
 		set_relation (entry, GTK_LABEL (label));
-		size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);		
-		button = gtk_button_new_with_mnemonic(_("_Add"));
-		gtk_size_group_add_widget (size_group, button);
+		button = gtk_button_new_from_stock (GTK_STOCK_ADD);
 		g_object_set_data (G_OBJECT (button), "entry", entry);
 		gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
 		soft_set_sensitive (button, FALSE);
@@ -1293,8 +1261,7 @@ static gint updateOutput(gpointer data)
 				  G_CALLBACK (add_button_clicked), stockdata);
 		g_signal_connect (G_OBJECT (entry), "changed",
 					  G_CALLBACK (entry_changed), button);
-		button = gtk_button_new_with_mnemonic(_("_Remove"));
-		gtk_size_group_add_widget (size_group, button);
+		button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
 		g_object_set_data (G_OBJECT (button), "list", list);
 		g_signal_connect (G_OBJECT (button), "clicked",
 				  G_CALLBACK (remove_symbol), stockdata);
@@ -1765,7 +1732,7 @@ static gint updateOutput(gpointer data)
 
 		gnome_vfs_init();
 		
-		gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-money.png");
+		gtk_window_set_default_icon_name ("gnome-money");
 		panel_applet_add_preferences (applet, "/schemas/apps/gtik/prefs", NULL);
 		panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 		
@@ -1864,7 +1831,7 @@ static gint updateOutput(gpointer data)
 		properties_set(stockdata,FALSE);
 		
 		panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
-                                                   NULL,
+                                                   DATADIR,
 				                   "GNOME_GtikApplet.xml",
                                                    NULL,
 				                   gtik_applet_menu_verbs,
@@ -1986,52 +1953,33 @@ static gint updateOutput(gpointer data)
 	}
 
 	/*-----------------------------------------------------------------*/
-	char *splitChange(StockData *stockdata,char *data, StockQuote *quote) {
-		char buff[MAX_SYMBOL_LEN]; 
-		static char buff2[MAX_SYMBOL_LEN];
+	char *splitChange(StockData *stockdata, char *data, StockQuote *quote) {
+		char *buff, *buff2;
 		char *var1, *var2, *var3, *var4;
-		char rise[2]; 
 
-                bzero(buff, MAX_SYMBOL_LEN); 
-                bzero(buff2, MAX_SYMBOL_LEN); 
-                bzero(rise, 2); 
-                
-		strcpy(buff,data);
+		buff = g_strdup (data);
 		var1 = strtok(buff,":");
 		var2 = strtok(NULL,":");
 		var3 = strtok(NULL,":");
 		var4 = strtok(NULL,"");
+		g_free (buff);
 
 		if (!var3 || !var4)
 			return NULL;
 
 		if (var4[0] == '+') { 
-#if 0
-			if (stockdata->symbolfont)
-				var3[0] = 221;
-#endif
-			var4[0] = '(';
 			quote->color = GREEN;
-			sprintf (rise, "+");
+			buff2 = g_strdup_printf (_("+%s (%s)"), var3, &var4[1]);
 		}
 		else if (var4[0] == '-') {
-#if 0
-			if (stockdata->symbolfont)
-				var3[0] = 223;	
-#endif
-			var4[0] = '(';
 			quote->color = RED;
+			buff2 = g_strdup_printf (_("%s (%s)"), var3, &var4[1]);
 		}
 		else {
-			/* TRANSLATOR: This forms part of a sentance
-			 * "(No Change)". FIXME: string composition is bad.
-			 */
-			var3 = g_strdup(_("(No Change"));
-			var4 = g_strdup("");
+			buff2 = g_strdup(_("(No Change)"));
 			quote->color = WHITE;
 		}
 
-		sprintf(buff2,"%s%s %s)",rise, var3,var4);
 		return(buff2);
 	}
 
@@ -2062,6 +2010,7 @@ static gint updateOutput(gpointer data)
 			quote.changelen = 0;
 			quote.changeheight = 0;
 		}
+		g_free (change);
 		 
 
 #if 0
@@ -2235,7 +2184,7 @@ static gint updateOutput(gpointer data)
 		
 	}
 
-	gchar* gtik_get_text(void) {
+	static gchar* gtik_get_text(void) {
 		GArray *quotes = access_stock->quotes;
 		gchar **strs = NULL;
 		gchar *buff;
